@@ -54,6 +54,15 @@ return dicto_widget_delete_query_dialog(GTK_WINDOW(window), file);
 static gboolean
 dicto_timed_cb(GtkWidget *dw, gpointer data)
 {
+GstTagSetter *ts;
+
+ts=dicto_get_tag_setter(d);
+if (ts) {
+	gst_tag_setter_add_tags(ts,
+    	GST_TAG_MERGE_REPLACE,
+    	GST_TAG_COMMENT, "ShortClip Test", NULL);
+} else g_debug("Current format does not support tags.");
+
 dicto_record_timeout(d, "shortclip.wav", 3.0);
 return FALSE;
 }
@@ -154,8 +163,6 @@ g_signal_connect(G_OBJECT(b), "clicked", G_CALLBACK(dicto_timed_cb), dw);
 g_signal_connect(G_OBJECT(dw), "delete-query", G_CALLBACK(dicto_delete_query_cb), dw);
 g_signal_connect(G_OBJECT(c), "changed", G_CALLBACK(dicto_format_select_cb), dw);
 
-g_object_set(dw, "enable-delete", TRUE, NULL);
-
 gtk_widget_show_all(window);
 gtk_main();
 
