@@ -49,7 +49,7 @@
 #include "dicto.h"
 #include "dicto-ui.h"
 
-#include "dicto-ui-marshal.h"
+#include "dicto-marshal.h"
 
 #ifndef HILDON_MARGIN_DEFAULT
 #define HILDON_MARGIN_DEFAULT 4
