@@ -44,7 +44,6 @@
 
 #include <glib.h>
 #include <glib/gstdio.h>
-#include <gtk/gtk.h>
 #include <gst/gst.h>
 
 #ifdef WITH_GIO
@@ -166,6 +165,12 @@ dicto_dispose(GObject *object)
 G_OBJECT_CLASS(dicto_parent_class)->dispose(object);
 }
 
+static gboolean
+dicto_true(void)
+{
+return TRUE;
+}
+
 static void
 dicto_pipeline_free(dicto_pipeline *np)
 {
@@ -1270,7 +1275,7 @@ if (!p->notes) {
 #if (GLIB_CHECK_VERSION (2, 12, 0))
 	g_hash_table_remove_all(p->notes);
 #else
-	g_hash_table_foreach_remove(p->notes, gtk_true, NULL);
+	g_hash_table_foreach_remove(p->notes, dicto_true, NULL);
 #endif
 }
 
