@@ -57,7 +57,7 @@ typedef enum {
 	DICTO_STATE_ERROR,
 } DictoState;
 
-#include <dicto/dicto-formats-enum.h>
+#include "dicto/dicto-formats-enum.h"
 
 #define	FORMAT_DEFAULT FORMAT_WAV_8K_16B_M
 
